@@ -2,14 +2,17 @@ from hestia_earth.schema import SchemaType, CycleFunctionalUnit, SiteSiteType, T
 from hestia_earth.utils.tools import flatten, list_sum
 from hestia_earth.utils.date import diff_in_days, is_in_days
 from hestia_earth.utils.api import find_node
+from hestia_earth.utils.model import find_term_match
+from hestia_earth.utils.lookup import get_table_value, download_lookup, column_name
 
 from hestia_earth.validation.utils import _find_linked_node, _value_average, _list_sum_terms
 from .shared import (
-    validate_dates, validate_list_dates, validate_date_lt_today, validate_list_min_max,
+    validate_dates, validate_list_dates, validate_date_lt_today, validate_list_min_below_max,
     validate_list_term_percent, validate_linked_source_privacy, validate_list_dates_length, validate_list_date_lt_today,
     validate_list_model, validate_list_model_config, validate_list_dates_format,
-    validate_list_duplicate_values, validate_private_has_source
+    validate_list_duplicate_values, validate_private_has_source, validate_list_value_between_min_max
 )
+from .emission import validate_linked_terms
 from .input import validate_must_include_id, validate_input_country, validate_related_impacts
 from .practice import (
     validate_cropResidueManagement, validate_longFallowPeriod, validate_excretaManagement, validate_no_tillage,
@@ -21,7 +24,8 @@ from .product import (
 )
 from .data_completeness import validate_dataCompleteness
 from .transformation import (
-    validate_previous_transformation, validate_first_transformation, validate_transformation_excretaManagement
+    validate_previous_transformation, validate_first_transformation_fields, validate_transformation_excretaManagement,
+    validate_first_transformation_input
 )
 from .property import (
     validate_valueType as validate_properties_valueType, validate_default_value as validate_properties_default_value
@@ -129,16 +133,6 @@ def validate_siteDuration(cycle: dict):
     })
 
 
-def validate_otherSites_length(cycle: dict):
-    otherSites = cycle.get('otherSites', [])
-    otherSitesDuration = cycle.get('otherSitesDuration', [])
-    return len(otherSites) == len(otherSitesDuration) or {
-        'level': 'error',
-        'dataPath': '.otherSitesDuration',
-        'message': 'must have the same length as otherSites'
-    }
-
-
 def validate_otherSites_cycleDuration(cycle: dict):
     cycleDuration = cycle.get('cycleDuration', 0)
     siteDuration = cycle.get('siteDuration')
@@ -150,6 +144,29 @@ def validate_otherSites_cycleDuration(cycle: dict):
     }
 
 
+def _product_cover_crop(product: dict):
+    term_id = product.get('term', {}).get('@id')
+    term_type = product.get('term', {}).get('termType')
+    lookup = download_lookup(f"{term_type}.csv")
+    is_cover_crop = get_table_value(lookup, 'termid', term_id, column_name('possibleCoverCrop'))
+    return not (not is_cover_crop)  # convert numpy boolean to boolean
+
+
+def validate_possibleCoverCrop(cycle: dict):
+    cover_crop = find_term_match(cycle.get('practices', []), 'coverCrop', None)
+    cover_crop_value = cover_crop.get('value', []) if cover_crop else None
+    has_cover_crop = cover_crop_value is not None and (
+        len(cover_crop_value) == 0 or (cover_crop_value[0] != 0 and cover_crop_value[0] != 'false')
+    )
+    invalid_product = next((p for p in cycle.get('products', []) if not _product_cover_crop(p)), None)
+
+    return not has_cover_crop or invalid_product is None or {
+        'level': 'error',
+        'dataPath': '',
+        'message': 'cover crop cycle contains non cover crop product'
+    }
+
+
 def validate_cycle(cycle: dict, node_map: dict = {}):
     """
     Validates a single `Cycle`.
@@ -177,24 +194,28 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_cycleDuration(cycle) if _should_validate_cycleDuration(cycle) else True,
         validate_dataCompleteness(cycle.get('dataCompleteness', {}), site) if 'dataCompleteness' in cycle else True,
         validate_siteDuration(cycle),
-        validate_otherSites_length(cycle),
-        validate_otherSites_cycleDuration(cycle)
+        validate_otherSites_cycleDuration(cycle),
+        validate_possibleCoverCrop(cycle)
     ]) + flatten([
         validate_list_model(cycle, 'emissions'),
         validate_list_dates(cycle, 'emissions'),
         validate_list_dates_format(cycle, 'emissions'),
-        validate_list_min_max(cycle, 'emissions'),
+        validate_list_min_below_max(cycle, 'emissions'),
+        validate_list_value_between_min_max(cycle, 'emissions'),
         validate_list_term_percent(cycle, 'emissions'),
         validate_list_dates_length(cycle, 'emissions'),
         validate_list_date_lt_today(cycle, 'emissions', ['startDate', 'endDate']),
         validate_properties_default_value(cycle, 'emissions'),
-        validate_properties_valueType(cycle, 'emissions')
+        validate_properties_valueType(cycle, 'emissions'),
+        validate_linked_terms(cycle, 'emissions', 'inputs', 'inputs'),
+        validate_linked_terms(cycle, 'emissions', 'transformation', 'transformations', True),
     ] if len(cycle.get('emissions', [])) > 0 else []) + flatten([
         validate_list_dates(cycle, 'inputs'),
         validate_list_dates_format(cycle, 'inputs'),
         validate_list_dates_length(cycle, 'inputs'),
         validate_list_date_lt_today(cycle, 'inputs', ['startDate', 'endDate']),
-        validate_list_min_max(cycle, 'inputs'),
+        validate_list_min_below_max(cycle, 'inputs'),
+        validate_list_value_between_min_max(cycle, 'inputs'),
         validate_list_term_percent(cycle, 'inputs'),
         validate_properties_default_value(cycle, 'inputs'),
         validate_properties_valueType(cycle, 'inputs'),
@@ -206,7 +227,8 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_list_dates_format(cycle, 'products'),
         validate_list_dates_length(cycle, 'products'),
         validate_list_date_lt_today(cycle, 'products', ['startDate', 'endDate']),
-        validate_list_min_max(cycle, 'products'),
+        validate_list_min_below_max(cycle, 'products'),
+        validate_list_value_between_min_max(cycle, 'products'),
         validate_list_term_percent(cycle, 'products'),
         validate_economicValueShare(cycle.get('products')),
         validate_sum_aboveGroundCropResidue(cycle.get('products')),
@@ -222,7 +244,8 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_list_dates(cycle, 'practices'),
         validate_list_dates_format(cycle, 'practices'),
         validate_list_date_lt_today(cycle, 'practices', ['startDate', 'endDate']),
-        validate_list_min_max(cycle, 'practices'),
+        validate_list_min_below_max(cycle, 'practices'),
+        validate_list_value_between_min_max(cycle, 'practices'),
         validate_list_term_percent(cycle, 'practices'),
         validate_cropResidueManagement(cycle.get('practices')),
         validate_longFallowPeriod(cycle.get('practices')),
@@ -240,6 +263,7 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_list_dates_format(cycle, 'transformations'),
         validate_list_date_lt_today(cycle, 'transformations', ['startDate', 'endDate']),
         validate_previous_transformation(cycle.get('transformations')),
-        validate_first_transformation(cycle.get('transformations')),
+        validate_first_transformation_fields(cycle.get('transformations')),
+        validate_first_transformation_input(cycle, cycle.get('transformations')),
         validate_transformation_excretaManagement(cycle.get('transformations'))
     ] if len(cycle.get('transformations', [])) > 0 in cycle else [])
