@@ -9,8 +9,8 @@ def validate_linked_terms(cycle: dict, list_key: str, linked_key: str, linked_li
 
     def validate(values: tuple):
         index, emission = values
-        linked_items = emission.get(linked_key)
-        return linked_items is None or any([
+        linked_items = emission.get(linked_key, [])
+        return len(linked_items) == 0 or any([
             find_term_match(linked_nodes, item.get('@id')) for item in (
                 [linked_items] if isinstance(linked_items, dict) else linked_items
             )
