@@ -1,9 +1,9 @@
 from hestia_earth.utils.tools import flatten
 
 from .shared import (
-    validate_list_min_max, validate_region_in_country, validate_country, validate_is_region,
+    validate_list_min_below_max, validate_region_in_country, validate_country, validate_is_region,
     validate_list_term_percent, validate_linked_source_privacy, validate_date_lt_today,
-    validate_list_model, validate_private_has_source
+    validate_list_model, validate_private_has_source, validate_list_value_between_min_max
 )
 from .indicator import validate_characterisedIndicator_model
 
@@ -34,11 +34,13 @@ def validate_impact_assessment(impact_assessment: dict, node_map: dict = {}):
         validate_region_in_country(impact_assessment) if 'region' in impact_assessment else True
     ] + flatten([
         validate_list_model(impact_assessment, 'impacts'),
-        validate_list_min_max(impact_assessment, 'impacts'),
+        validate_list_min_below_max(impact_assessment, 'impacts'),
+        validate_list_value_between_min_max(impact_assessment, 'impacts'),
         validate_list_term_percent(impact_assessment, 'impacts'),
         validate_characterisedIndicator_model(impact_assessment, 'impacts')
     ] if 'impacts' in impact_assessment else []) + flatten([
-        validate_list_min_max(impact_assessment, 'emissionsResourceUse'),
+        validate_list_min_below_max(impact_assessment, 'emissionsResourceUse'),
+        validate_list_value_between_min_max(impact_assessment, 'emissionsResourceUse'),
         validate_list_term_percent(impact_assessment, 'emissionsResourceUse'),
         validate_characterisedIndicator_model(impact_assessment, 'emissionsResourceUse')
     ] if 'emissionsResourceUse' in impact_assessment else [])
