@@ -4,6 +4,10 @@ from hestia_earth.utils.lookup import download_lookup, get_table_value, column_n
 
 from hestia_earth.validation.utils import _filter_list_errors
 
+IGNORE_MODELS = [
+    'aggregatedModels'  # used only for aggregations, should not be shown as possible values
+]
+
 
 def _methodModels():
     terms = find_node(SchemaType.TERM, {'termType': TermTermType.MODEL.value}, limit=1000)
@@ -11,7 +15,11 @@ def _methodModels():
 
 
 def _allowed_characterisedIndicator_model(lookup, models: list, term_id: str):
-    return [m for m in models if m != 'termid' and get_table_value(lookup, 'termid', term_id, column_name(m))]
+    return [
+        m for m in models if m != 'termid' and
+        get_table_value(lookup, 'termid', term_id, column_name(m)) and
+        m not in IGNORE_MODELS
+    ]
 
 
 def _is_method_allowed(lookup, term_id: str, model: str):
@@ -21,7 +29,7 @@ def _is_method_allowed(lookup, term_id: str, model: str):
 
 
 def validate_characterisedIndicator_model(node: dict, list_key: str):
-    lookup = download_lookup('characterisedIndicator-model-mapping.csv')
+    lookup = download_lookup('characterisedIndicator-model-mapping.csv', keep_in_memory=False)
     models = _methodModels()
 
     def validate(values: tuple):
