@@ -40,6 +40,8 @@ def validate_valueType(node: dict, list_key: str):
 def _property_default_value(term_id: str, property_term_id: str):
     # load the term defaultProperties and find the matching property
     term = download_hestia(term_id)
+    if not term:
+        raise Exception(f"Term not found: {term_id}")
     return safe_parse_float(find_term_match(term.get('defaultProperties', []), property_term_id).get('value'))
 
 
