@@ -261,12 +261,22 @@ def need_validate_area(node: dict): return 'area' in node and 'boundary' in node
 
 
 def validate_area(node: dict):
+    threshold = 0.05
+
     try:
-        area = get_geojson_area(node.get('boundary'))
-        return area == round(node.get('area'), 1) or {
+        value = round(node.get('area'), 1)
+        expected_value = get_geojson_area(node.get('boundary'))
+        delta = value_difference(value, expected_value) if expected_value else 0
+        return delta < threshold or {
             'level': 'error',
             'dataPath': '.area',
-            'message': f"must be equal to boundary (~{area})"
+            'message': f"must be equal to boundary (~{expected_value})",
+            'params': {
+                'current': value,
+                'expected': expected_value,
+                'delta': delta * 100,
+                'threshold': threshold
+            }
         }
     except KeyError:
         # if getting the geojson fails, the geojson format is invalid
