@@ -50,7 +50,7 @@ def validate_previous_transformation(transformations: list):
     return _filter_list_errors(flatten(map(validate, range(1, len(transformations)))))
 
 
-def validate_first_transformation(transformations: list):
+def validate_first_transformation_fields(transformations: list):
     tr = transformations[0] if len(transformations) > 0 else None
 
     def validate(field: str):
@@ -63,6 +63,20 @@ def validate_first_transformation(transformations: list):
     return not tr or _filter_list_errors(map(validate, ['previousTransformationTerm', 'previousTransformationShare']))
 
 
+def validate_first_transformation_input(cycle: dict, transformations: list):
+    tr = transformations[0] if len(transformations) > 0 else None
+
+    def cycle_has_product(input: dict):
+        term_id = input.get('term', {}).get('@id')
+        return find_term_match(cycle.get('products', []), term_id, None) is not None
+
+    return not tr or any([cycle_has_product(i) for i in tr.get('inputs', [])]) or {
+        'level': 'error',
+        'dataPath': '.transformations[0]',
+        'message': 'at least one Input must be a Product of the Cycle'
+    }
+
+
 def validate_transformation_excretaManagement(transformations: list):
     def validate(values: tuple):
         index, transformation = values
