@@ -147,7 +147,7 @@ def test_validate_depths_invalid():
     assert validate_depths(data.get('nodes')) == {
         'level': 'error',
         'dataPath': '.measurements[2].depthLower',
-        'message': 'must be greater than depthUpper'
+        'message': 'must be greater than or equal to depthUpper'
     }
 
 
